# ozi-spec CHANGELOG
## 0.9.1 (2024-08-28)


### 🐛 Fixed Bugs

* correct key typo — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`0805bac`](https://github.com/OZI-Project/ozi-spec/commit/0805bacc3f17c982acc362aee1ce8734f6b04339))

* project-url to project-urls list — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`5871986`](https://github.com/OZI-Project/ozi-spec/commit/58719861cb8cf5f2f27bf35a9d7ced44ffe42c88))

* update pyproject.toml for OZI 1.20 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`881b79a`](https://github.com/OZI-Project/ozi-spec/commit/881b79aa722ba215c60a559cf23cb9886a878d90))


### Performance


* perf: OZI.build[core]~=1.4.3 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`ed66155`](https://github.com/OZI-Project/ozi-spec/commit/ed66155c592a98b28a31e38de4e7218d2414039e))

## 0.9.0 (2024-08-27)


### Feature


* feat: remove requirements.in target OZI.build 1.3 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`7cf50c3`](https://github.com/OZI-Project/ozi-spec/commit/7cf50c36db9266c65a83e7f19d4f93e7e92e732d))

## 0.8.1 (2024-08-23)


### 🐛 Fixed Bugs

* pin spec to 0.8 and OZI to 1.19 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`54718a3`](https://github.com/OZI-Project/ozi-spec/commit/54718a326cffd2e8494d9dea6fc6ae6e91cdc9d2))

## 0.8.0 (2024-08-23)

## 0.7.0 (2024-08-22)


### Build


* (deps): bump OZI-Project/publish from 0.1.9 to 0.1.10

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.9 to 0.1.10.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.9...0.1.10)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`82eec52`](https://github.com/OZI-Project/ozi-spec/commit/82eec52f2529583143254b00b602c1d82fe7ef4d))

* (deps): bump OZI-Project/checkpoint from 0.5.1 to 0.5.2

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.1 to 0.5.2.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.1...0.5.2)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`c4926bc`](https://github.com/OZI-Project/ozi-spec/commit/c4926bc1b82a5217c9f0e56fdd5e868962b0e2ed))

* (deps): bump OZI-Project/draft from 0.3.8 to 0.3.9

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.8 to 0.3.9.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.8...0.3.9)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`1b46763`](https://github.com/OZI-Project/ozi-spec/commit/1b46763411561d769d696ec9fe819c750ccadc92))

* (deps): bump OZI-Project/release from 0.8.9 to 0.8.10

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.8.9 to 0.8.10.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.8.9...0.8.10)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`9a18441`](https://github.com/OZI-Project/ozi-spec/commit/9a1844126123239242f7a4af5aab989025ecf02b))


### Feature


* feat: OZI.build renders optional_dependencies — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`f8f5088`](https://github.com/OZI-Project/ozi-spec/commit/f8f50889523cd26362001821d77dbe94df9692f1))

* feat: add invoke to build-system deps

also patches github workflows — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`fa7e9cf`](https://github.com/OZI-Project/ozi-spec/commit/fa7e9cfbaa34d5562d4d1be24f5f12774fc735da))

## 0.6.1 (2024-08-16)


### 🐛 Fixed Bugs

* Merge pull request #41 from OZI-Project/0.6

0.6
([`0132861`](https://github.com/OZI-Project/ozi-spec/commit/0132861b435a6a2159ec2c4a63cc786359efc494))


### Unknown


* :pencil2: OZI 1.18 and spec 0.6 pin versions — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`7992390`](https://github.com/OZI-Project/ozi-spec/commit/79923901da0352a028ffcc010904ed2185caf3f0))

## 0.6.0 (2024-08-16)


### Feature


* feat: added ``cibuildwheel`` and ``twine`` as plugins

Also pins pip-tools~=7.4, OZI.build~=1.0.2, tox~=4.18, tox-gh~=1.3 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`02062f1`](https://github.com/OZI-Project/ozi-spec/commit/02062f1fbf2a8d1750bab9e3855152eeb7d118e6))


### Unknown


* :rotating_light: run black — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`abf9aa2`](https://github.com/OZI-Project/ozi-spec/commit/abf9aa2902c8a77b032a9aa3457226942599f5ec))

## 0.5.10 (2024-08-12)


### Build


* (deps): bump OZI-Project/release from 0.7.4 to 0.8.9

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.4 to 0.8.9.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.7.4...0.8.9)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`268f056`](https://github.com/OZI-Project/ozi-spec/commit/268f0564ec46b9e561a8358b480cc3d42f003b1c))

* (deps): bump OZI-Project/release from 0.7.3 to 0.7.4

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.7.3 to 0.7.4.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.7.3...0.7.4)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`cc6207c`](https://github.com/OZI-Project/ozi-spec/commit/cc6207cc12c76bbec4f3f3e18041dd36456d089e))

* (deps): bump OZI-Project/checkpoint from 0.5.0 to 0.5.1

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.5.0 to 0.5.1.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.5.0...0.5.1)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`7263fec`](https://github.com/OZI-Project/ozi-spec/commit/7263fec1eea67c623fa65c798e0f8e1b1b2df2f3))

* (deps): bump OZI-Project/draft from 0.3.7 to 0.3.8

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.7 to 0.3.8.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.7...0.3.8)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`821e408`](https://github.com/OZI-Project/ozi-spec/commit/821e4084616885747547bcf332a7adad26f0cd1e))

* (deps): bump step-security/harden-runner from 2.9.0 to 2.9.1

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.9.0 to 2.9.1.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/0d381219ddf674d61a7572ddd19d7941e271515c...5c7944e73c4c2a096b17a9cb74d65b6c2bbafbde)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`4886f1f`](https://github.com/OZI-Project/ozi-spec/commit/4886f1f45ba30e4c61906322c5673bbf7413a25e))


### Performance


* perf(ci.py): Release version=0.8.9 — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`8d7e85c`](https://github.com/OZI-Project/ozi-spec/commit/8d7e85c67c83c7b6ee92e1b6a166d7785b8b7d6e))

## 0.5.9 (2024-08-05)


### Performance


* perf: Bump OZI-Project/draft from 0.3.7 to 0.3.8 — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`b4422c2`](https://github.com/OZI-Project/ozi-spec/commit/b4422c232cd3e91bc829d17475418d93bab5ac71))

* perf: Bump OZI-Project/release from 0.7.3 to 0.7.4 — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`b97460b`](https://github.com/OZI-Project/ozi-spec/commit/b97460b613a7d397b160cf4430b55b17b18a45d9))

* perf: Bump OZI-Project/checkpoint from 0.5.0 to 0.5.1 — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`b2369f7`](https://github.com/OZI-Project/ozi-spec/commit/b2369f7bdeae8881de0b73a0b8bf86e7dc74b120))

## 0.5.8 (2024-07-29)


### Performance


* perf: draft 0.3.7 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`9356eec`](https://github.com/OZI-Project/ozi-spec/commit/9356eecbfd41c2c59f0eb821051e5c0c871293f4))

* perf: publish 0.1.9 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`c5fbfcb`](https://github.com/OZI-Project/ozi-spec/commit/c5fbfcb46b50f8212c28ecb5d2def521179e45a9))

## 0.5.7 (2024-07-25)


### Build


* (deps): bump OZI-Project/publish from 0.1.8 to 0.1.9

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.8 to 0.1.9.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.8...0.1.9)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`6ad4dff`](https://github.com/OZI-Project/ozi-spec/commit/6ad4dff4be252202a93f012b009ed43a4f324086))

* (deps): bump OZI-Project/draft from 0.3.6 to 0.3.7

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.6 to 0.3.7.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.6...0.3.7)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`731cd8e`](https://github.com/OZI-Project/ozi-spec/commit/731cd8e0fba988578d0017af49140c179262afc2))


### 🐛 Fixed Bugs

* OZI default version 1.17 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`018880d`](https://github.com/OZI-Project/ozi-spec/commit/018880de8601b6930aef6a26d0e59f8a772700e6))

## 0.5.6 (2024-07-22)


### 🐛 Fixed Bugs

* correct ``templates/templates/*`` names to include ``.j2`` extension
([`cf1094e`](https://github.com/OZI-Project/ozi-spec/commit/cf1094e8e598afdd62e1d90a87415b699e2bf2a5))

## 0.5.5 (2024-07-19)


### 🐛 Fixed Bugs

* use sigstore-v3 actions in github CI — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`d45030f`](https://github.com/OZI-Project/ozi-spec/commit/d45030ffefea9496ed296614451e5ea7e15d97cf))

## 0.5.4 (2024-07-18)


### Build


* (deps): bump OZI-Project/release from 0.6.5 to 0.7.3

Bumps [OZI-Project/release](https://github.com/ozi-project/release) from 0.6.5 to 0.7.3.
- [Release notes](https://github.com/ozi-project/release/releases)
- [Commits](https://github.com/ozi-project/release/compare/0.6.5...0.7.3)


updated-dependencies:
- dependency-name: OZI-Project/release
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`15ac435`](https://github.com/OZI-Project/ozi-spec/commit/15ac4353be38569289103aed8404f3e9bb1601a1))

* (deps): bump OZI-Project/checkpoint from 0.4.2 to 0.5.0

Bumps [OZI-Project/checkpoint](https://github.com/ozi-project/checkpoint) from 0.4.2 to 0.5.0.
- [Release notes](https://github.com/ozi-project/checkpoint/releases)
- [Commits](https://github.com/ozi-project/checkpoint/compare/0.4.2...0.5.0)


updated-dependencies:
- dependency-name: OZI-Project/checkpoint
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`770d374`](https://github.com/OZI-Project/ozi-spec/commit/770d374d80d8690502aa6337846896a62546f197))

* (deps): bump OZI-Project/draft from 0.3.3 to 0.3.6

Bumps [OZI-Project/draft](https://github.com/ozi-project/draft) from 0.3.3 to 0.3.6.
- [Release notes](https://github.com/ozi-project/draft/releases)
- [Commits](https://github.com/ozi-project/draft/compare/0.3.3...0.3.6)


updated-dependencies:
- dependency-name: OZI-Project/draft
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`219a326`](https://github.com/OZI-Project/ozi-spec/commit/219a326e38ea6d4e63e458e0ff493d4a098d6f50))

* (deps): bump step-security/harden-runner from 2.8.0 to 2.9.0

Bumps [step-security/harden-runner](https://github.com/step-security/harden-runner) from 2.8.0 to 2.9.0.
- [Release notes](https://github.com/step-security/harden-runner/releases)
- [Commits](https://github.com/step-security/harden-runner/compare/v2.8.0...0d381219ddf674d61a7572ddd19d7941e271515c)


updated-dependencies:
- dependency-name: step-security/harden-runner
  dependency-type: direct:production
  update-type: version-update:semver-minor
... — dependabot[bot] &lt;support@github.com&gt;
([`f98d0e8`](https://github.com/OZI-Project/ozi-spec/commit/f98d0e8a55cfcf6cc30f3363d5ce94ee21ac2290))

* (deps): bump OZI-Project/publish from 0.1.6 to 0.1.8

Bumps [OZI-Project/publish](https://github.com/ozi-project/publish) from 0.1.6 to 0.1.8.
- [Release notes](https://github.com/ozi-project/publish/releases)
- [Commits](https://github.com/ozi-project/publish/compare/0.1.6...0.1.8)


updated-dependencies:
- dependency-name: OZI-Project/publish
  dependency-type: direct:production
  update-type: version-update:semver-patch
... — dependabot[bot] &lt;support@github.com&gt;
([`751407a`](https://github.com/OZI-Project/ozi-spec/commit/751407ab63ad8a2cdbc133b5e392efe29385974c))


### Performance


* perf: Merge pull request #19 from OZI-Project/feature/sigstore-v3

Feature/sigstore v3
([`65f6b21`](https://github.com/OZI-Project/ozi-spec/commit/65f6b216257474dda90fc8a47eb285bd8841f63d))


### Unknown


* Update dependabot.yml — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`88c5e71`](https://github.com/OZI-Project/ozi-spec/commit/88c5e716e0e82ea2ac0d98dc6dff312d74dc93b2))

* Create dependabot.yml — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`a5c8af8`](https://github.com/OZI-Project/ozi-spec/commit/a5c8af8b6d8e72f4a57433ef2c1052ffdb296113))

## 0.5.3 (2024-07-18)


### 🐛 Fixed Bugs

* OZI.build&gt;=0.0.27 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`4fd6a01`](https://github.com/OZI-Project/ozi-spec/commit/4fd6a0120d4ccf080d6ec21540874931d4bca0bd))

## 0.5.2 (2024-07-16)


### Performance


* perf: OZI-Project/draft@0.3.5 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`6344e19`](https://github.com/OZI-Project/ozi-spec/commit/6344e1920ea5e033c062c62bba4a3e7ec70cbcad))

* perf: OZI-Project/checkpoint@0.4.3 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`37f3cdb`](https://github.com/OZI-Project/ozi-spec/commit/37f3cdba726c2c921762bac49bad2e38aac3353c))

* perf: OZI-Project/release@0.6.6 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`49a6d93`](https://github.com/OZI-Project/ozi-spec/commit/49a6d939d5e2808c1de1205974c6c90fd8db4b0e))

* perf: OZI-Project/publish@0.1.8 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`1699c50`](https://github.com/OZI-Project/ozi-spec/commit/1699c5023b492fe2ed49d7340c702abd74f14789))

## 0.5.1 (2024-07-11)


### 🐛 Fixed Bugs

* update version — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`158212b`](https://github.com/OZI-Project/ozi-spec/commit/158212baf2061b55a99c556bc0f1862498ba16ac))

## 0.5.0 (2024-07-07)


### Performance


* perf: run black — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`a2f0bc8`](https://github.com/OZI-Project/ozi-spec/commit/a2f0bc8356204624cbbf719f363272ef7531e1ed))

## 0.4.1 (2024-07-01)

## 0.4.0 (2024-07-01)


### 👷 Updated Continuous Integration

* add 0.x branch pattern — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`5d606c8`](https://github.com/OZI-Project/ozi-spec/commit/5d606c850a9316b1b9f7ecf0cc7c9897b82f6fa1))


### Feature


* feat(src.py SrcTemplate): add ``templates``, ``subprojects`` and modified ``ci_provider`` to be a dictionary of tuples — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`6dbd31c`](https://github.com/OZI-Project/ozi-spec/commit/6dbd31c9f0a1053ed0b544c954cc71c20bf150b3))

* feat: tag OZI 1.14
([`b6cb028`](https://github.com/OZI-Project/ozi-spec/commit/b6cb0285901d95512e7545c06edd7f2c539c4125))


### 🐛 Fixed Bugs

* update commit parser templates — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`4975a1c`](https://github.com/OZI-Project/ozi-spec/commit/4975a1cc3e3e10b38cae41e5584b92649505eb4e))

* individual file license/copyright header corrected to Unlicense
([`74ff29c`](https://github.com/OZI-Project/ozi-spec/commit/74ff29cc0ea4e991cddffd1da6f553eb1fbb40a8))

* doc and download link metadata — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`8c849f6`](https://github.com/OZI-Project/ozi-spec/commit/8c849f692a566ff65499712f38e3b10da86b1dc8))


### Performance


* perf: OZI-Project/draft@0.3.4 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`e747e9b`](https://github.com/OZI-Project/ozi-spec/commit/e747e9b1c5caeb5c54c51f66a30eab7b57850878))

* perf: OZI-Project/publish@0.1.7 — rjdbcm &lt;rjdbcm@outlook.com&gt;
([`c224b07`](https://github.com/OZI-Project/ozi-spec/commit/c224b078da4060195d040dec97abb58ca12fb057))


### Unknown


* Update requirements.in — Eden Ross Duff, MSc &lt;rjdbcm@outlook.com&gt;
([`a0bcce3`](https://github.com/OZI-Project/ozi-spec/commit/a0bcce34cf6ba9abfd1bdc0685ae9d6c62a7c742))

## 0.3.0 (2024-07-01)


### Feature


* feat: init from OZI 1.13.31 spec submodule source
([`434d1db`](https://github.com/OZI-Project/ozi-spec/commit/434d1db4aff6652cd9b88002d18c4d14f55cbd0d))
